#[repr(C)]pub struct GpioReadResponse {
pub value: bool,
}Fields
value: boolTrait Implementations
Sourceimpl Clone for GpioReadResponse
impl Clone for GpioReadResponse
Sourcefn clone(&self) -> GpioReadResponse
fn clone(&self) -> GpioReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GpioReadResponse
impl Debug for GpioReadResponse
Sourceimpl<'a, ___E> Encode<GpioReadResponse, ___E> for &'a GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GpioReadResponse, ___E> for &'a GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioReadResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioReadResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GpioReadResponse, ___E> for GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GpioReadResponse, ___E> for GpioReadResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, GpioReadResponse>
const COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, GpioReadResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioReadResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioReadResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GpioReadResponse>, ___E> for &'a GpioReadResponse
impl<'a, ___E> EncodeOption<Box<'static, GpioReadResponse>, ___E> for &'a GpioReadResponse
Sourcefn encode_option(
this: Option<&'a GpioReadResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioReadResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GpioReadResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioReadResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GpioReadResponse>, ___E> for GpioReadResponse
impl<___E> EncodeOption<Box<'static, GpioReadResponse>, ___E> for GpioReadResponse
Sourcefn encode_option(
this: Option<GpioReadResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioReadResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GpioReadResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioReadResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GpioReadResponse> for GpioReadResponse
impl FromWire<GpioReadResponse> for GpioReadResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, GpioReadResponse>
const COPY_OPTIMIZATION: CopyOptimization<GpioReadResponse, GpioReadResponse>
Sourcefn from_wire(wire: GpioReadResponse) -> GpioReadResponse
fn from_wire(wire: GpioReadResponse) -> GpioReadResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<GpioReadResponse> for GpioReadResponse
impl FromWireRef<GpioReadResponse> for GpioReadResponse
Sourcefn from_wire_ref(wire: &GpioReadResponse) -> GpioReadResponse
fn from_wire_ref(wire: &GpioReadResponse) -> GpioReadResponse
Converts the given reference to this type.
Sourceimpl Hash for GpioReadResponse
impl Hash for GpioReadResponse
Sourceimpl Ord for GpioReadResponse
impl Ord for GpioReadResponse
Sourcefn cmp(&self, other: &GpioReadResponse) -> Ordering
fn cmp(&self, other: &GpioReadResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioReadResponse
impl PartialEq for GpioReadResponse
Sourcefn eq(&self, other: &GpioReadResponse) -> bool
fn eq(&self, other: &GpioReadResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioReadResponse
impl PartialOrd for GpioReadResponse
impl Copy for GpioReadResponse
impl Eq for GpioReadResponse
impl StructuralPartialEq for GpioReadResponse