#[repr(C)]pub struct GpioGetInterruptResponse {
pub interrupt: Interrupt,
}Fields
interrupt: InterruptTrait Implementations
Sourceimpl Debug for GpioGetInterruptResponse
impl Debug for GpioGetInterruptResponse
Sourceimpl<___E> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GpioGetInterruptResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, GpioGetInterruptResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GpioGetInterruptResponse>, ___E> for GpioGetInterruptResponse
impl<___E> EncodeOption<Box<'static, GpioGetInterruptResponse>, ___E> for GpioGetInterruptResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioGetInterruptResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioGetInterruptResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GpioGetInterruptResponse> for GpioGetInterruptResponse
impl FromWire<GpioGetInterruptResponse> for GpioGetInterruptResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptResponse, Self>
Sourcefn from_wire(wire: GpioGetInterruptResponse) -> Self
fn from_wire(wire: GpioGetInterruptResponse) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for GpioGetInterruptResponse
impl PartialEq for GpioGetInterruptResponse
Sourcefn eq(&self, other: &GpioGetInterruptResponse) -> bool
fn eq(&self, other: &GpioGetInterruptResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GpioGetInterruptResponse