#[repr(C)]pub struct GpioGetInterruptRequest {
pub options: InterruptOptions,
}Fields
options: InterruptOptionsTrait Implementations
Sourceimpl Clone for GpioGetInterruptRequest
impl Clone for GpioGetInterruptRequest
Sourcefn clone(&self) -> GpioGetInterruptRequest
fn clone(&self) -> GpioGetInterruptRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GpioGetInterruptRequest
impl Debug for GpioGetInterruptRequest
Sourceimpl<'a, ___E> Encode<GpioGetInterruptRequest, ___E> for &'a GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GpioGetInterruptRequest, ___E> for &'a GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GpioGetInterruptRequest>, ___E> for &'a GpioGetInterruptRequest
impl<'a, ___E> EncodeOption<Box<'static, GpioGetInterruptRequest>, ___E> for &'a GpioGetInterruptRequest
Sourcefn encode_option(
this: Option<&'a GpioGetInterruptRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioGetInterruptRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a GpioGetInterruptRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioGetInterruptRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GpioGetInterruptRequest>, ___E> for GpioGetInterruptRequest
impl<___E> EncodeOption<Box<'static, GpioGetInterruptRequest>, ___E> for GpioGetInterruptRequest
Sourcefn encode_option(
this: Option<GpioGetInterruptRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GpioGetInterruptRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<GpioGetInterruptRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GpioGetInterruptRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GpioGetInterruptRequest> for GpioGetInterruptRequest
impl FromWire<GpioGetInterruptRequest> for GpioGetInterruptRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
Sourcefn from_wire(wire: GpioGetInterruptRequest) -> GpioGetInterruptRequest
fn from_wire(wire: GpioGetInterruptRequest) -> GpioGetInterruptRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<GpioGetInterruptRequest> for GpioGetInterruptRequest
impl FromWireRef<GpioGetInterruptRequest> for GpioGetInterruptRequest
Sourcefn from_wire_ref(wire: &GpioGetInterruptRequest) -> GpioGetInterruptRequest
fn from_wire_ref(wire: &GpioGetInterruptRequest) -> GpioGetInterruptRequest
Converts the given reference to this type.
Sourceimpl Hash for GpioGetInterruptRequest
impl Hash for GpioGetInterruptRequest
Sourceimpl Ord for GpioGetInterruptRequest
impl Ord for GpioGetInterruptRequest
Sourcefn cmp(&self, other: &GpioGetInterruptRequest) -> Ordering
fn cmp(&self, other: &GpioGetInterruptRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GpioGetInterruptRequest
impl PartialEq for GpioGetInterruptRequest
Sourcefn eq(&self, other: &GpioGetInterruptRequest) -> bool
fn eq(&self, other: &GpioGetInterruptRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GpioGetInterruptRequest
impl PartialOrd for GpioGetInterruptRequest
impl Copy for GpioGetInterruptRequest
impl Eq for GpioGetInterruptRequest
impl StructuralPartialEq for GpioGetInterruptRequest