#[repr(C)]pub struct GpioGetInterruptRequest {
pub options: InterruptOptions,
}Expand description
The wire type corresponding to GpioGetInterruptRequest.
Fields
options: InterruptOptionsTrait Implementations
Sourceimpl Clone for GpioGetInterruptRequest
impl Clone for GpioGetInterruptRequest
Sourcefn clone(&self) -> GpioGetInterruptRequest
fn clone(&self) -> GpioGetInterruptRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GpioGetInterruptRequest
impl Constrained for GpioGetInterruptRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, GpioGetInterruptRequest>,
_: <GpioGetInterruptRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, GpioGetInterruptRequest>, _: <GpioGetInterruptRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for GpioGetInterruptRequest
impl Debug for GpioGetInterruptRequest
Sourceimpl<___D> Decode<___D> for GpioGetInterruptRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GpioGetInterruptRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GpioGetInterruptRequest, ___E> for &'a GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GpioGetInterruptRequest, ___E> for &'a GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<InterruptOptions, ___E>,
impl<___E, T0> Encode<GpioGetInterruptRequest, ___E> for GpioGetInterruptRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<InterruptOptions, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GpioGetInterruptRequest> for GpioGetInterruptRequest
impl FromWire<GpioGetInterruptRequest> for GpioGetInterruptRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptRequest, GpioGetInterruptRequest>
Sourcefn from_wire(wire: GpioGetInterruptRequest) -> GpioGetInterruptRequest
fn from_wire(wire: GpioGetInterruptRequest) -> GpioGetInterruptRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<GpioGetInterruptRequest> for GpioGetInterruptRequest
impl FromWireRef<GpioGetInterruptRequest> for GpioGetInterruptRequest
Sourcefn from_wire_ref(wire: &GpioGetInterruptRequest) -> GpioGetInterruptRequest
fn from_wire_ref(wire: &GpioGetInterruptRequest) -> GpioGetInterruptRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for GpioGetInterruptRequest
impl IntoNatural for GpioGetInterruptRequest
Sourcetype Natural = GpioGetInterruptRequest
type Natural = GpioGetInterruptRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GpioGetInterruptRequest
impl Wire for GpioGetInterruptRequest
Sourcetype Narrowed<'de> = GpioGetInterruptRequest
type Narrowed<'de> = GpioGetInterruptRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<GpioGetInterruptRequest>)
fn zero_padding(out_: &mut MaybeUninit<GpioGetInterruptRequest>)
Writes zeroes to the padding for this type, if any.