#[repr(C)]pub struct GpioGetInterruptResponse {
pub interrupt: Interrupt,
}Expand description
The wire type corresponding to GpioGetInterruptResponse.
Fields
interrupt: InterruptTrait Implementations
Sourceimpl Constrained for GpioGetInterruptResponse
impl Constrained for GpioGetInterruptResponse
Sourceimpl Debug for GpioGetInterruptResponse
impl Debug for GpioGetInterruptResponse
Sourceimpl<___D> Decode<___D> for GpioGetInterruptResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for GpioGetInterruptResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GpioGetInterruptResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, GpioGetInterruptResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
impl<___E, T0> Encode<GpioGetInterruptResponse, ___E> for GpioGetInterruptResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Interrupt, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GpioGetInterruptResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GpioGetInterruptResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GpioGetInterruptResponse> for GpioGetInterruptResponse
impl FromWire<GpioGetInterruptResponse> for GpioGetInterruptResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<GpioGetInterruptResponse, Self>
Sourcefn from_wire(wire: GpioGetInterruptResponse) -> Self
fn from_wire(wire: GpioGetInterruptResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for GpioGetInterruptResponse
impl IntoNatural for GpioGetInterruptResponse
Sourcetype Natural = GpioGetInterruptResponse
type Natural = GpioGetInterruptResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GpioGetInterruptResponse
impl Wire for GpioGetInterruptResponse
Sourcetype Narrowed<'de> = GpioGetInterruptResponse
type Narrowed<'de> = GpioGetInterruptResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.